@@ -1,17 +1,14 @@
 package Email::Sender::Failure::Permanent;
-our $VERSION = '0.092840';
-
-
+our $VERSION = '0.100460';
 use Moose;
 extends 'Email::Sender::Failure';
 # ABSTRACT: a permanent delivery failure
 
-__PACKAGE__->meta->make_immutable;
+__PACKAGE__->meta->make_immutable(inline_constructor => 0);
 no Moose;
 1;
 
 __END__
-
 =pod
 
 =head1 NAME
@@ -20,7 +17,7 @@ Email::Sender::Failure::Permanent - a permanent delivery failure
 
 =head1 VERSION
 
-version 0.092840
+version 0.100460
 
 =head1 AUTHOR
 
@@ -28,11 +25,10 @@ version 0.092840
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2009 by Ricardo Signes.
+This software is copyright (c) 2010 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
-=cut 
-
+=cut
 
